@@ -1,5 +1,5 @@
 /*
- * Copyright 2002-2016 the original author or authors.
+ * Copyright 2002-2017 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -44,8 +44,18 @@ import org.springframework.http.converter.GenericHttpMessageConverter;
 import org.springframework.http.converter.HttpMessageConverter;
 import org.springframework.web.util.DefaultUriTemplateHandler;
 
-import static org.junit.Assert.*;
-import static org.mockito.BDDMockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertSame;
+import static org.junit.Assert.fail;
+import static org.mockito.BDDMockito.any;
+import static org.mockito.BDDMockito.eq;
+import static org.mockito.BDDMockito.given;
+import static org.mockito.BDDMockito.mock;
+import static org.mockito.BDDMockito.verify;
+import static org.mockito.BDDMockito.willThrow;
+import static org.springframework.http.MediaType.parseMediaType;
 
 /**
  * @author Arjen Poutsma
@@ -69,7 +79,7 @@ public class RestTemplateTests {
 
 
 	@Before
-	public void setUp() {
+	public void setup() {
 		requestFactory = mock(ClientHttpRequestFactory.class);
 		request = mock(ClientHttpRequest.class);
 		response = mock(ClientHttpResponse.class);
@@ -146,6 +156,21 @@ public class RestTemplateTests {
 		verify(response).close();
 	}
 
+	@Test  // SPR-15201
+	public void uriTemplateWithTrailingSlash() throws Exception {
+		String url = "http://example.com/spring/";
+		given(requestFactory.createRequest(new URI(url), HttpMethod.GET)).willReturn(request);
+		given(request.execute()).willReturn(response);
+		given(errorHandler.hasError(response)).willReturn(false);
+		HttpStatus status = HttpStatus.OK;
+		given(response.getStatusCode()).willReturn(status);
+		given(response.getStatusText()).willReturn(status.getReasonPhrase());
+
+		template.execute(url, HttpMethod.GET, null, null);
+
+		verify(response).close();
+	}
+
 	@Test
 	public void errorHandling() throws Exception {
 		given(requestFactory.createRequest(new URI("http://example.com"), HttpMethod.GET)).willReturn(request);
@@ -265,7 +290,6 @@ public class RestTemplateTests {
 
 	@Test
 	public void getForObjectWithCustomUriTemplateHandler() throws Exception {
-
 		DefaultUriTemplateHandler uriTemplateHandler = new DefaultUriTemplateHandler();
 		uriTemplateHandler.setParsePath(true);
 		template.setUriTemplateHandler(uriTemplateHandler);
@@ -292,7 +316,6 @@ public class RestTemplateTests {
 		verify(response).close();
 	}
 
-
 	@Test
 	public void headForHeaders() throws Exception {
 		given(requestFactory.createRequest(new URI("http://example.com"), HttpMethod.HEAD)).willReturn(request);
@@ -688,9 +711,7 @@ public class RestTemplateTests {
 		verify(response).close();
 	}
 
-	// Issue: SPR-9325, SPR-13860
-
-	@Test
+	@Test // Issue: SPR-9325, SPR-13860
 	public void ioException() throws Exception {
 		String url = "http://example.com/resource?access_token=123";
 
@@ -712,6 +733,29 @@ public class RestTemplateTests {
 		}
 	}
 
+	@Test // SPR-15900
+	public void ioExceptionWithEmptyQueryString() throws Exception {
+
+		// http://example.com/resource?
+		URI uri = new URI("http", "example.com", "/resource", "", null);
+
+		given(converter.canRead(String.class, null)).willReturn(true);
+		given(converter.getSupportedMediaTypes()).willReturn(Collections.singletonList(parseMediaType("foo/bar")));
+		given(requestFactory.createRequest(uri, HttpMethod.GET)).willReturn(request);
+		given(request.getHeaders()).willReturn(new HttpHeaders());
+		given(request.execute()).willThrow(new IOException("Socket failure"));
+
+		try {
+			template.getForObject(uri, String.class);
+			fail("RestClientException expected");
+		}
+		catch (ResourceAccessException ex) {
+			assertEquals("I/O error on GET request for \"http://example.com/resource\": " +
+					"Socket failure; nested exception is java.io.IOException: Socket failure",
+					ex.getMessage());
+		}
+	}
+
 	@Test
 	public void exchange() throws Exception {
 		given(converter.canRead(Integer.class, null)).willReturn(true);
